@@ -135,12 +135,6 @@ class DistributionBranchTests(BuilddebTestCase):
         version = Version(version_no)
         self.assertEqual(db.tag_name(version), version_no)
 
-    def test_upstream_tag_name(self):
-        db = self.db1
-        upstream_v_no = "0.1"
-        self.assertEqual(db.upstream_tag_name(upstream_v_no),
-                "upstream-" + upstream_v_no)
-
     def test_tag_version(self):
         db = self.db1
         tree = self.tree1
@@ -156,7 +150,7 @@ class DistributionBranchTests(BuilddebTestCase):
         version = "0.1"
         revid = tree.commit("one")
         db.tag_upstream_version(version)
-        tag_name = db.upstream_tag_name(version)
+        tag_name = db.pristine_tar_source.tag_name(version)
         self.assertEqual(tree.branch.tags.lookup_tag(tag_name), revid)
 
     def test_has_version(self):
@@ -1499,7 +1493,7 @@ class DistributionBranchTests(BuilddebTestCase):
             tf.add("a")
         finally:
             tf.close()
-        conflicts = db.merge_upstream(tarball_filename, "0.2", "0.1")
+        conflicts = db.merge_upstream(tarball_filename, "foo", "0.2", "0.1")
         self.assertEqual(0,  conflicts)
 
     def test_merge_upstream_initial_with_branch(self):
@@ -1536,9 +1530,9 @@ class DistributionBranchTests(BuilddebTestCase):
             tf.add("a")
         finally:
             tf.close()
-        conflicts = db.merge_upstream(tarball_filename, "0.2", "0.1",
-                upstream_branch=upstream_tree.branch,
-                upstream_revision=upstream_rev)
+        conflicts = db.merge_upstream(tarball_filename, "foo", "0.2", "0.1",
+            upstream_branch=upstream_tree.branch,
+            upstream_revision=upstream_rev)
         self.assertEqual(0,  conflicts)
 
     def test_merge_upstream_initial_with_removed_debian(self):
@@ -1576,9 +1570,9 @@ class DistributionBranchTests(BuilddebTestCase):
             tf.add("a")
         finally:
             tf.close()
-        conflicts = db.merge_upstream(tarball_filename, "0.2", "0.1",
-                upstream_branch=upstream_tree.branch,
-                upstream_revision=upstream_rev)
+        conflicts = db.merge_upstream(tarball_filename, "foo", "0.2", "0.1",
+            upstream_branch=upstream_tree.branch,
+            upstream_revision=upstream_rev)
         # ./debian conflicts.
         self.assertEqual(3,  conflicts)
 
@@ -1617,7 +1611,7 @@ class DistributionBranchTests(BuilddebTestCase):
         dbs.add_branch(db)
         tree.lock_write()
         self.addCleanup(tree.unlock)
-        db.merge_upstream(builder.tar_name(), str(version2),
+        db.merge_upstream(builder.tar_name(), "package", str(version2),
             version1.upstream_version,
             upstream_branch=upstream_tree.branch,
             upstream_revision=upstream_rev)
@@ -1656,7 +1650,8 @@ class DistributionBranchTests(BuilddebTestCase):
             tf.add("a")
         finally:
             tf.close()
-        conflicts = db.merge_upstream(tarball_filename, "0.2-1", "0.1")
+        conflicts = db.merge_upstream(tarball_filename, "package", "0.2-1",
+            "0.1")
         # Check that we tagged wiht the dash version
         self.assertTrue(tree.branch.tags.has_tag('upstream-0.2-1'))
 
@@ -1694,7 +1689,8 @@ class DistributionBranchTests(BuilddebTestCase):
         # We don't add the new file upstream, as the new file id would
         # be picked up from there.
         upstream_rev2 = upstream_tree.commit("two")
-        db.merge_upstream(builder.tar_name(), version2.upstream_version,
+        db.merge_upstream(builder.tar_name(), "package",
+            version2.upstream_version,
             version1.upstream_version,
             upstream_branch=upstream_tree.branch,
             upstream_revision=upstream_rev2)
@@ -1730,12 +1726,44 @@ class DistributionBranchTests(BuilddebTestCase):
         # We don't add the new file upstream, as the new file id would
         # be picked up from there.
         upstream_rev2 = upstream_tree.commit("two")
-        db.merge_upstream(builder.tar_name(), version2.upstream_version,
+        db.merge_upstream(builder.tar_name(), "package",
+            version2.upstream_version,
             version1.upstream_version,
             upstream_branch=upstream_tree.branch,
             upstream_revision=upstream_rev2)
         self.assertEqual("a-id", tree.path2id("b"))
 
+    def test_merge_upstream_rename_in_packaging_branch(self):
+        """Test renaming a file in the packaging branch."""
+        self.requireFeature(PristineTarFeature)
+        version1 = Version("1.0-1")
+        version2 = Version("1.1-1")
+        packaging_tree = self.make_branch_and_tree("packaging")
+        packaging_tree.lock_write()
+        self.addCleanup(packaging_tree.unlock)
+        self.build_tree(['packaging/a'])
+        packaging_tree.add(['a'], ['a-id'])
+        upstream_rev1 = packaging_tree.commit("one")
+        db = DistributionBranch(packaging_tree.branch, None,
+            tree=packaging_tree)
+        dbs = DistributionBranchSet()
+        dbs.add_branch(db)
+        packaging_tree.rename_one('a', 'b')
+        self.build_tree(['packaging/a'])
+        packaging_tree.add(['a'], ['other-a-id'])
+        packaging_tree.commit("add packaging")
+        packaging_tree.branch.tags.set_tag("upstream-%s" % version1.upstream_version,
+                upstream_rev1)
+        builder = SourcePackageBuilder("package", version2)
+        builder.add_default_control()
+        builder.add_upstream_file("a", "New a")
+        builder.add_upstream_file("b", "Renamed a")
+        builder.build()
+        db.merge_upstream(builder.tar_name(), "packaging",
+            version2.upstream_version, version1.upstream_version)
+        self.assertEqual("a-id", packaging_tree.path2id("b"))
+        self.assertEqual("other-a-id", packaging_tree.path2id("a"))
+
     def test_import_symlink(self):
         version = Version("1.0-1")
         self.requireFeature(PristineTarFeature)
@@ -1889,20 +1917,3 @@ class SourceExtractorTests(tests.TestCaseInTempDir):
         finally:
             extractor.cleanup()
 
-
-class PossibleUpstreamTagNamesTests(BuilddebTestCase):
-
-    def setUp(self):
-        super(PossibleUpstreamTagNamesTests, self).setUp()
-        self.tree = self.make_branch_and_tree('unstable')
-        root_id = self.tree.path2id("")
-        self.up_tree = self.make_branch_and_tree('unstable-upstream')
-        self.up_tree.set_root_id(root_id)
-        self.db = DistributionBranch(self.tree.branch,
-                self.up_tree.branch, tree=self.tree,
-                upstream_tree=self.up_tree)
-
-    def test_version(self):
-        self.assertEquals(['upstream-3.3', 'upstream-debian-3.3',
-            'upstream-ubuntu-3.3', 'upstream/3.3'],
-            self.db.possible_upstream_tag_names("3.3"))
